hotspot/test/compiler/intrinsics/sha/TestSHA.java
changeset 40059 c2304140ed64
parent 24953 9680119572be
child 41705 332239c052cc
--- a/hotspot/test/compiler/intrinsics/sha/TestSHA.java	Tue Jul 12 08:42:46 2016 +0000
+++ b/hotspot/test/compiler/intrinsics/sha/TestSHA.java	Tue Jul 12 18:24:48 2016 +0300
@@ -27,26 +27,58 @@
  * @bug 8035968
  * @summary C2 support for SHA on SPARC
  *
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-224 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-384 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-512 TestSHA
  *
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Doffset=1 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-224 -Doffset=1 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 -Doffset=1 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-384 -Doffset=1 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-512 -Doffset=1 TestSHA
  *
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Dalgorithm2=SHA-256 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Dalgorithm2=SHA-512 TestSHA
  * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 -Dalgorithm2=SHA-512 TestSHA
  *
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Dalgorithm2=MD5     TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=MD5     -Dalgorithm2=SHA-1   TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-1   -Dalgorithm2=MD5
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=MD5     -Dalgorithm2=SHA-1
+ *      compiler.intrinsics.sha.TestSHA
  */
 
+package compiler.intrinsics.sha;
+
 import java.security.MessageDigest;
 import java.util.Arrays;
 
@@ -70,7 +102,7 @@
         }
     }
 
-    static void testSHA(String provider, String algorithm, int msgSize,
+    public static void testSHA(String provider, String algorithm, int msgSize,
                         int offset, int iters, int warmupIters) throws Exception {
         System.out.println("provider = " + provider);
         System.out.println("algorithm = " + algorithm);
@@ -27,26 +27,58 @@
  * @summary C2 support for SHA on SPARC
  *
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-224 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-384 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-512 TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-1
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-224
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-256
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-384
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-512
+ *      compiler.intrinsics.sha.TestSHA
  *
@@ -27,26 +27,58 @@
  *
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Doffset=1 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-224 -Doffset=1 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 -Doffset=1 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-384 -Doffset=1 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-512 -Doffset=1 TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-1   -Doffset=1
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-224 -Doffset=1
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-256 -Doffset=1
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-384 -Doffset=1
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-512 -Doffset=1
+ *      compiler.intrinsics.sha.TestSHA
  *
@@ -27,26 +27,58 @@
  *
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Dalgorithm2=SHA-256 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-1   -Dalgorithm2=SHA-512 TestSHA
- * @run main/othervm/timeout=600 -Xbatch -Dalgorithm=SHA-256 -Dalgorithm2=SHA-512 TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-1   -Dalgorithm2=SHA-256
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-1   -Dalgorithm2=SHA-512
+ *      compiler.intrinsics.sha.TestSHA
+ * @run main/othervm/timeout=600 -Xbatch
+ *      -Dalgorithm=SHA-256 -Dalgorithm2=SHA-512
+ *      compiler.intrinsics.sha.TestSHA
  *